@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Engelsk (USA)",
+"sq": "Albansk",
 "am": "Amharisk",
 "ar": "Arabisk",
 "ast": "Asturisk",
-"bg": "Bulgarsk",
 "bn": "Bengalsk",
 "bn-IN": "Bengalsk (India)",
-"bo": "Tibetansk",
 "bs": "Bosnisk",
+"bg": "Bulgarsk",
 "ca": "Katalansk",
-"ca-valencia": "Valenciansk katalansk",
-"cs": "Tjekkisk",
+"ca-valencia": "Katalansk (Valencia)",
+"zh-CN": "Kinesisk (forenkla)",
+"zh-TW": "Kinesisk (tradisjonell)",
+"hr": "Kroatisk",
+"cs": "Tsjekkisk",
 "da": "Dansk",
-"de": "Tysk",
+"nl": "Nederlandsk",
 "dz": "Dzongkha",
-"el": "Gresk",
 "en-GB": "Engelsk (UK)",
 "en-ZA": "Engelsk (SA)",
 "eo": "Esperanto",
-"es": "Spansk",
 "et": "Estisk",
 "eu": "Baskisk",
 "fi": "Finsk",
 "fr": "Fransk",
 "gl": "Galisisk",
+"ka": "Georgisk",
+"de": "Tysk",
+"el": "Gresk",
 "gu": "Gujarati",
 "he": "Hebraisk",
 "hi": "Hindi",
-"hr": "Kroatisk",
 "hu": "Ungarsk",
 "id": "Indonesisk",
 "is": "Islandsk",
 "it": "Italiensk",
 "ja": "Japansk",
-"ka": "Georgisk",
 "km": "Khmer",
 "ko": "Koreansk",
 "lo": "Laotisk",
-"lt": "Litauisk",
 "lv": "Latvisk",
+"lt": "Litauisk",
 "mk": "Makedonsk",
-"nb": "Norsk bokmål",
 "ne": "Nepalesisk",
-"nl": "Nederlandsk",
 "nn": "Norsk nynorsk",
+"nb": "Norsk bokmål",
 "om": "Oromo",
 "pl": "Polsk",
 "pt": "Portugisisk",
-"pt-BR": "Brasiliansk portugisisk",
+"pt-BR": "Portugisisk (Brazil)",
 "ro": "Rumensk",
 "ru": "Russisk",
-"si": "Singalesisk",
 "sid": "Sidama",
+"si": "Singalesisk",
 "sk": "Slovakisk",
 "sl": "Slovensk",
-"sq": "Albansk",
+"dsb": "Sorbisk (nedre)",
+"hsb": "Sorbisk (øvre)",
+"es": "Spansk",
 "sv": "Svensk",
-"ta": "Tamilsk",
 "tg": "Tadsjikisk",
+"ta": "Tamilsk",
+"bo": "Tibetansk",
 "tr": "Tyrkisk",
 "ug": "Uigurisk",
 "uk": "Ukrainsk",
 "vi": "Vietnamesisk",
-"zh-CN": "Kinesisk (forenkla)",
-"zh-TW": "Kinesisk (tradisjonell)",
 };
